@@ -294,7 +294,11 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE,
   period_string <- paste0("\nAnalysed Period: ", result_daily_response[[4]])
 
   if (result_daily_response[[2]] == 'cor'){
-    method_string <- paste0("\nMethod: Pearson Correlation")
+    method_string <- paste0("\nMethod: Correlation Coefficient (", result_daily_response[[3]], ")")
+
+  } else if (result_daily_response[[2]] == 'pcor'){
+    method_string <- paste0("\nMethod: Partial Correlation Coefficient (", result_daily_response[[3]], ")")
+
   } else if (result_daily_response[[2]] == 'lm'){
     method_string <- paste0("\nMethod: Linear Regression")
   } else if (result_daily_response[[2]] == 'brnn'){
@@ -303,6 +307,8 @@ plot_specific <- function(result_daily_response, window_width, title = TRUE,
 
 
 
+
+
   final_plot <- final_plot +
     ggtitle(paste0(optimal_window_string, period_string, method_string,
                    optimal_calculation, reference_string, Optimal_string)) +
